@@ -70,10 +70,10 @@ bibtexdirectin_initparams( param *pm, const char *progname )
 	slist_init( &(pm->asis) );
 	slist_init( &(pm->corps) );
 
- 	// TODO: these probably should be made parameters, as the others above;
-	//       note that 'find' and 'replace' work in tandem, so both need to be cleared.
-	slist_free( &find );
-	slist_free( &replace );
+ 	// // TODO: these probably should be made parameters, as the others above;
+	// //       note that 'find' and 'replace' work in tandem, so both need to be cleared.
+	// slist_free( &find );
+	// slist_free( &replace );
 
 	if ( !progname ) pm->progname = NULL;
 	else {
@@ -84,6 +84,17 @@ bibtexdirectin_initparams( param *pm, const char *progname )
 	return BIBL_OK;
 }
 
+// Georgi
+// void (*more_cleanf)()
+void bibdirectin_more_cleanf()
+{
+  // TODO: these probably should be made parameters, as the others above;
+  //       note that 'find' and 'replace' work in tandem, so both need to be cleared.
+  slist_free( &find );
+  slist_free( &replace );
+}
+
+
 /*****************************************************
  PUBLIC: int bibtexdirectin_readf()
 *****************************************************/
